#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 08/04/2025

##@package vmp_net
#
# Wrapper c++ namespace vampiria::net

from vmp_net_ import is_ipv4_raw           as is_ipv4_raw
from vmp_net_ import ipv4_subnet           as ipv4_subnet
from vmp_net_ import ipv4_expand           as ipv4_expand
from vmp_net_ import ipv4_to_net           as ipv4_to_net
from vmp_net_ import is_ipv6_raw           as is_ipv6_raw
from vmp_net_ import ipv6_subnet           as ipv6_subnet
from vmp_net_ import ipv6_to_net           as ipv6_to_net
from vmp_net_ import ipv6_addr_contracted  as ipv6_addr_contracted
from vmp_net_ import is_ip_raw             as is_ip_raw
from vmp_net_ import ip_to_buf             as ip_to_buf
from vmp_net_ import ipv4_from_buf         as ipv4_from_buf
from vmp_net_ import ipv6_from_buf         as ipv6_from_buf
from vmp_net_ import iface_mac             as iface_mac
from vmp_net_ import iface_ipv4            as iface_ipv4
from vmp_net_ import iface_ipv4_netmask    as iface_ipv4_netmask
from vmp_net_ import iface_ipv4_broadcast  as iface_ipv4_broadcast
from vmp_net_ import iface_ipv4_mtu        as iface_ipv4_mtu
from vmp_net_ import is_macaddress_raw     as is_macaddress_raw
from vmp_net_ import macaddress_to_buf     as macaddress_to_buf
from vmp_net_ import macaddress_from_buf   as macaddress_from_buf

from vmp_net_ import CONN_NONE         as CONN_NONE
from vmp_net_ import CONN_UDP4         as CONN_UDP4
from vmp_net_ import CONN_UDP6         as CONN_UDP6
from vmp_net_ import CONN_UDPCONNECT   as CONN_UDPCONNECT
from vmp_net_ import CONN_UDPPROXY     as CONN_UDPPROXY
from vmp_net_ import CONN_TCPLISTEN    as CONN_TCPLISTEN
from vmp_net_ import CONN_TCPSERVER    as CONN_TCPSERVER
from vmp_net_ import CONN_TCPCLIENT    as CONN_TCPCLIENT
from vmp_net_ import CONN_TCPPROXY     as CONN_TCPPROXY
from vmp_net_ import CONN_TCPBIND      as CONN_TCPBIND
from vmp_net_ import CONN_TCPBINDPROXY as CONN_TCPBINDPROXY

from vmp_net_ import conn_strtype     as conn_strtype

from vmp_net_ import socks_cd_connect      as socks_cd_connect
from vmp_net_ import socks_cd_bind         as socks_cd_bind
from vmp_net_ import socks_cd_udpassociate as socks_cd_udpassociate

from vmp_net_ import socks4_result_granted         as socks4_result_granted
from vmp_net_ import socks4_result_failed          as socks4_result_failed
from vmp_net_ import socks4_result_reject          as socks4_result_reject
from vmp_net_ import socks4_result_rejectuserid    as socks4_result_rejectuserid
from vmp_net_ import socks5_result_ok              as socks5_result_ok
from vmp_net_ import socks5_result_failure         as socks5_result_failure
from vmp_net_ import socks5_result_notallowed      as socks5_result_notallowed
from vmp_net_ import socks5_result_netunreachable  as socks5_result_netunreachable
from vmp_net_ import socks5_result_hostunreachable as socks5_result_hostunreachable
from vmp_net_ import socks5_result_refused         as socks5_result_refused
from vmp_net_ import socks5_result_ttlexpired      as socks5_result_ttlexpired 
from vmp_net_ import socks5_result_badcmd          as socks5_result_badcmd 
from vmp_net_ import socks5_result_badatype        as socks5_result_badatype 
from vmp_net_ import socks_internal_badauth        as socks_internal_badauth
from vmp_net_ import socks_internal_badaddr        as socks_internal_badaddr 
from vmp_net_ import socks_internal_accessdenied   as socks_internal_accessdenied 
from vmp_net_ import socks_msg_result              as socks_msg_result 

from vmp_net_ import evtsocks_status_init        as evtsocks_status_init
from vmp_net_ import evtsocks_status_request     as evtsocks_status_request
from vmp_net_ import evtsocks_status_bind        as evtsocks_status_bind
from vmp_net_ import evtsocks_status_established as evtsocks_status_established
from vmp_net_ import evtsocks_status_close       as evtsocks_status_close

from vmp_net_ import Proxy                         as Proxy
from vmp_net_ import ProxyChain                    as ProxyChain

from vmp_net_ import UDP_MSIZE_DEFAULT     as UDP_MSIZE_DEFAULT
from vmp_net_ import socket_datagram       as socket_datagram
from vmp_net_ import socket_stream         as socket_stream
from vmp_net_ import socket_connect        as socket_connect
from vmp_net_ import socket_connect_check  as socket_connect_check
from vmp_net_ import socket_bind           as socket_bind
from vmp_net_ import socket_listen         as socket_listen
from vmp_net_ import socket_accept         as socket_accept
from vmp_net_ import socket_addrlocal      as socket_addrlocal
from vmp_net_ import socket_addrpeer       as socket_addrpeer
from vmp_net_ import socket_close          as socket_close
from vmp_net_ import socket_timeout        as socket_timeout
from vmp_net_ import socket_recvFrom       as socket_recvFrom
from vmp_net_ import socket_recv           as socket_recv
from vmp_net_ import socket_sendTo         as socket_sendTo
from vmp_net_ import socket_send           as socket_send

from vmp_net_ import tcp_resolve4          as tcp_resolve4
from vmp_net_ import tcp_resolve6          as tcp_resolve6
from vmp_net_ import tcp_resolveMX         as tcp_resolveMX

from vmp_net_ import Address             as Address
from vmp_net_ import MacAddress          as MacAddress
from vmp_net_ import udpui               as udpui
from vmp_net_ import UdpUI               as UdpUI
from vmp_net_ import tcpui               as tcpui
from vmp_net_ import TcpUI               as TcpUI
from vmp_net_ import socksui             as socksui
from vmp_net_ import SocksUI             as SocksUI

